# remirepo/Fedora spec file for php-laminas-di3
#
# Copyright (c) 2015-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global bootstrap    0
%global gh_commit    45c9dfd57370617d2028e597061c4ef2a2ea0118
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     laminas
%global gh_project   laminas-di
%global php_home     %{_datadir}/php
%global namespace    Laminas
%global library      Di
%global major        3
%if %{bootstrap}
%global with_tests   0%{?_with_tests:1}
%else
%global with_tests   0%{!?_without_tests:1}
%endif

Name:           php-%{gh_project}%{major}
Version:        3.11.0
Release:        1%{?dist}
Summary:        Laminas Framework %{library} component v%{major}

License:        BSD
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{gh_commit}/%{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
# Tests
%if %{with_tests}
BuildRequires:  php(language) >= 8.0
BuildRequires:  php-reflection
BuildRequires:  php-pcre
BuildRequires:  php-spl
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-autoloader(%{gh_owner}/laminas-stdlib)               >= 3.6   with php-autoloader(%{gh_owner}/laminas-stdlib)               < 4)
BuildRequires: (php-composer(psr/container)                              >= 1.1.1 with php-composer(psr/container)                              < 2)
BuildRequires: (php-composer(psr/log)                                    >= 1.1.4 with php-composer(psr/log)                                    < 2)
# From composer, "require-dev": {
#        "laminas/laminas-coding-standard": "^2.4.0",
#        "laminas/laminas-servicemanager": "^3.12",
#        "mikey179/vfsstream": "^1.6.11@alpha",
#        "phpbench/phpbench": "^1.2.7",
#        "phpunit/phpunit": "^9.5.26",
#        "psalm/plugin-phpunit": "^0.16.1",
#        "squizlabs/php_codesniffer": "^3.7.1",
#        "vimeo/psalm": "^4.10"
BuildRequires: (php-autoloader(%{gh_owner}/laminas-servicemanager)       >= 3.12   with php-autoloader(%{gh_owner}/laminas-servicemanager)       < 4)
BuildRequires: (php-composer(mikey179/vfsstream)                         >= 1.6.11 with php-composer(mikey179/vfsstream)                         < 2)
BuildRequires: (php-composer(phpspec/prophecy-phpunit)                   >= 2.0    with php-composer(phpspec/prophecy-phpunit)                   < 3)
# remirepo:8
%else
BuildRequires:  php-laminas-stdlib                                       >= 3.6
BuildRequires:  php-psr-container                                        >= 1.1.1
BuildRequires:  php-PsrLog                                               >= 1.1.4
BuildRequires:  php-laminas-servicemanager                               >= 3.12
BuildRequires:  php-mikey179-vfsstream                                   >= 1.6.7
BuildRequires:  php-phpspec-prophecy-phpunit                             >= 2.0
%endif
BuildRequires:  phpunit9 >= 9.5.26
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "~8.0.0 || ~8.1.0 || ~8.2.0",
#        "laminas/laminas-stdlib": "^3.6",
#        "psr/container": "^1.1.1",
#        "psr/log": "^1.1.4 || ^3.0.0"
Requires:       php(language) >= 8.0
%if ! %{bootstrap}
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-autoloader(%{gh_owner}/laminas-stdlib)               >= 3.6   with php-autoloader(%{gh_owner}/laminas-stdlib)               < 4)
Requires:      (php-composer(psr/container)                              >= 1.1.1 with php-composer(psr/container)                              < 2)
Requires:      (php-composer(psr/log)                                    >= 1.1.4 with php-composer(psr/log)                                    < 2)
# From composer, "require": {
#        "laminas/laminas-servicemanager": "An IoC container without auto wiring capabilities"
Suggests:       php-autoloader(%{gh_owner}/laminas-servicemanager)
# remirepo:5
%else
Requires:       php-laminas-stdlib                                       >= 3.6
Requires:       php-psr-container                                        >= 1.1.1
Requires:       php-PsrLog                                               >= 1.1.4
%endif
%endif
# Autoloader
Requires:       php-composer(fedora/autoloader)
# From phpcompatinfo report for version 3.1.2
Requires:       php-reflection
Requires:       php-pcre
Requires:       php-spl

Provides:       php-composer(%{gh_owner}/%{gh_project})   = %{version}
Provides:       php-autoloader(%{gh_owner}/%{gh_project}) = %{version}


%description
%{gh_project} is an example of an Inversion of Control (IoC) container.
IoC containers are widely used to create object instances that have all
dependencies resolved and injected. Dependency Injection containers are
one form of IoC – but not the only form.

Documentation: https://docs.laminas.dev/%{gh_project}/


%prep
%setup -q -n %{gh_project}-%{gh_commit}

mv LICENSE.md LICENSE

: Fix installation layout
mv templates src/
sed -e 's:/../../templates:/../templates:' -i src/CodeGenerator/*php


%build
: Create autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/%{namespace}/Stdlib/autoload.php',
    '%{php_home}/Psr/Container/autoload.php',
    [
        '%{php_home}/Psr/Log3/autoload.php',
        '%{php_home}/Psr/Log/autoload.php',
    ],
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_home}/%{namespace}/ServiceManager/autoload.php',
]);
EOF


%install
: Laminas library
mkdir -p   %{buildroot}%{php_home}/%{namespace}/
cp -pr src %{buildroot}%{php_home}/%{namespace}/%{library}%{major}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{php_home}/%{namespace}/%{library}%{major}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('%{namespace}Test\\%{library}\\', dirname(__DIR__) . '/test');
\Fedora\Autoloader\Autoload::addPsr4('%{namespace}Bench\\%{library}\\', dirname(__DIR__) . '/benchmarks');
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/org/bovigo/vfs/autoload.php',
    '%{php_home}/Prophecy/PhpUnit/autoload.php',
]);
EOF

ret=0
for cmd in php php80 php81 php82; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit9 \
      --verbose || ret=1
  fi
done


exit $ret
%else
: Test suite disabled
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{php_home}/%{namespace}/%{library}%{major}


%changelog
* Fri Nov 25 2022 Remi Collet <remi@remirepo.net> - 3.11.0-1
- update to 3.11.0
- raise dependency on PHP 8.0

* Thu Jun 30 2022 Remi Collet <remi@remirepo.net> - 3.9.1-1
- update to 3.9.1
- allow psr/log v3

* Thu Jun 30 2022 Remi Collet <remi@remirepo.net> - 3.8.0-1
- update to 3.8.0

* Thu Jun 23 2022 Remi Collet <remi@remirepo.net> - 3.7.0-2
- drop dependency on container-interop/container-interop
  replaced by servicemanager >= 3.12

* Mon May 16 2022 Remi Collet <remi@remirepo.net> - 3.7.0-1
- update to 3.7.0

* Mon May  9 2022 Remi Collet <remi@remirepo.net> - 3.5.0-1
- update to 3.5.0

* Mon Feb 28 2022 Remi Collet <remi@remirepo.net> - 3.4.0-1
- update to 3.4.0
- raise dependency on PHP 7.4

* Fri Sep 24 2021 Remi Collet <remi@remirepo.net> - 3.3.0-1
- update to 3.3.0
- raise dependency on laminas-stdlib 3.6
- raise dependency on psr/container 1.1.1
- drop dependency on laminas-zendframework-bridge

* Wed Apr 14 2021 Remi Collet <remi@remirepo.net> - 3.2.2-1
- update to 3.2.2
- drop ZF compatibility

* Mon Jan  4 2021 Remi Collet <remi@remirepo.net> - 3.2.1-1
- update to 3.2.1 (no change)

* Wed Oct 21 2020 Remi Collet <remi@remirepo.net> - 3.2.0-1
- update to 3.2.0
- raise dependency on PHP 7.3
- raise dependency on zend-stdlib >= 3.3
- switch to phpunit9

* Wed Sep 16 2020 Remi Collet <remi@remirepo.net> - 3.1.3-1
- update to 3.1.3

* Thu Jan 23 2020 Remi Collet <remi@remirepo.net> - 3.1.2-1
- update to 3.1.2
- rename to php-laminas-di3
- move to /usr/share/php/Laminas/Di3
- raise dependency on PHP 7.1
- add dependency on psr/container
- add dependency on psr/log

* Fri Jan 17 2020 Remi Collet <remi@remirepo.net> - 2.6.1-2
- cleanup

* Tue Jan  7 2020 Remi Collet <remi@remirepo.net> - 2.6.1-1
- switch to Laminas

* Thu Feb 28 2019 Remi Collet <remi@remirepo.net> - 2.6.1-8
- use range dependencies

* Tue Dec  5 2017 Remi Collet <remi@remirepo.net> - 2.6.1-4
- switch from zend-loader to fedora/autoloader

* Tue Apr 26 2016 Remi Collet <remi@fedoraproject.org> - 2.6.1-1
- update to 2.6.1

* Wed Feb 24 2016 Remi Collet <remi@fedoraproject.org> - 2.6.0-1
- update to 2.6.0
- add dependency on container-interop/container-interop
- raise dependency on zend-code >= 2.6
- raise dependency on zend-stdlib >= 2.7

* Tue Aug  4 2015 Remi Collet <remi@fedoraproject.org> - 2.5.1-1
- initial package
